@@ -14,6 +14,7 @@ from anki.utils import ids2str, intTime, json, isWin, isMac, platDesc, checksum
 from anki.consts import *
 from hooks import runHook
 import anki
+from lang import ngettext
 
 # syncing vars
 HTTP_TIMEOUT = 90
@@ -110,23 +111,22 @@ class Syncer(object):
         self.col.log("rmeta", meta)
         if not meta:
             return "badAuth"
+        # server requested abort?
+        self.syncMsg = meta['msg']
+        if not meta['cont']:
+            return "serverAbort"
+        else:
+            # don't abort, but if 'msg' is not blank, gui should show 'msg'
+            # after sync finishes and wait for confirmation before hiding
+            pass
         rscm = meta['scm']
         rts = meta['ts']
         self.rmod = meta['mod']
         self.maxUsn = meta['usn']
-        self.mediaUsn = meta['musn']
-        self.syncMsg = meta['msg']
         # this is a temporary measure to address the problem of users
         # forgetting which email address they've used - it will be removed
         # when enough time has passed
         self.uname = meta.get("uname", "")
-        # server requested abort?
-        if not meta['cont']:
-            return "serverAbort"
-        else:
-            # don't abort, but ui should show message after sync finishes
-            # and require confirmation if it's non-empty
-            pass
         meta = self.meta()
         self.col.log("lmeta", meta)
         self.lmod = meta['mod']
@@ -182,7 +182,7 @@ class Syncer(object):
         if ret['status'] != "ok":
             # roll back and force full sync
             self.col.rollback()
-            self.col.modSchema()
+            self.col.modSchema(False)
             self.col.save()
             return "sanityCheckFailed"
         # finalize
@@ -320,7 +320,7 @@ from notes where %s""" % d)
 
     def chunk(self):
         buf = dict(done=False)
-        lim = 2500
+        lim = 250
         while self.tablesLeft and lim:
             curTable = self.tablesLeft[0]
             if not self.cursor:
@@ -740,6 +740,7 @@ class MediaSyncer(object):
 
         # loop through and process changes from server
         self.col.log("last local usn is %s"%lastUsn)
+        self.downloadCount = 0
         while True:
             data = self.server.mediaChanges(lastUsn=lastUsn)
 
@@ -789,11 +790,16 @@ class MediaSyncer(object):
         # and we need to send our own
 
         updateConflict = False
+        toSend = self.col.media.dirtyCount()
         while True:
             zip, fnames = self.col.media.mediaChangesZip()
             if not fnames:
                 break
 
+            runHook("syncMsg", ngettext(
+                "%d media change to upload", "%d media changes to upload", toSend)
+                    % toSend)
+
             processedCnt, serverLastUsn = self.server.uploadChanges(zip)
             self.col.media.markClean(fnames[0:processedCnt])
 
@@ -811,6 +817,8 @@ class MediaSyncer(object):
                 self.col.media.db.commit()
                 updateConflict = True
 
+            toSend -= processedCnt
+
         if updateConflict:
             self.col.log("restart sync due to concurrent update")
             return self.sync()
@@ -830,15 +838,14 @@ class MediaSyncer(object):
             self.col.log("fetch %s"%top)
             zipData = self.server.downloadFiles(files=top)
             cnt = self.col.media.addFilesFromZip(zipData)
+            self.downloadCount += cnt
             self.col.log("received %d files"%cnt)
             fnames = fnames[cnt:]
 
-    def files(self):
-        return self.col.media.addFilesToZip()
-
-    def addFiles(self, zip):
-        "True if zip is the last in set. Server returns new usn instead."
-        return self.col.media.addFilesFromZip(zip)
+            n = self.downloadCount
+            runHook("syncMsg", ngettext(
+                "%d media file downloaded", "%d media files downloaded", n)
+                    % n)
 
 # Remote media syncing
 ##########################################################################
@@ -852,7 +859,7 @@ class RemoteMediaServer(HttpSyncer):
     def syncURL(self):
         if os.getenv("DEV"):
             return "https://l1.ankiweb.net/msync/"
-        return SYNC_BASE + "msync/"
+        return SYNC_MEDIA_BASE
 
     def begin(self):
         self.postVars = dict(
